import { Component, EventEmitter, HostBinding, Input, NgModule, Output, ViewChild } from "@angular/core";
import { NG_VALUE_ACCESSOR } from "@angular/forms";
import { IgxRippleModule } from "../directives/ripple/ripple.directive";
export var LabelPosition;
(function (LabelPosition) {
    LabelPosition["BEFORE"] = "before";
    LabelPosition["AFTER"] = "after";
})(LabelPosition || (LabelPosition = {}));
var noop = function () { };
var ɵ0 = noop;
var nextId = 0;
/**
 * **Ignite UI for Angular Checkbox** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/checkbox.html)
 *
 * The Ignite UI Checkbox is a selection control that allows users to make a binary choice. It behaves similarly
 * to the native browser checkbox.
 *
 * Example:
 * ```html
 * <igx-checkbox checked="true">
 *   simple checkbox
 * </igx-checkbox>
 * ```
 */
var IgxCheckboxComponent = /** @class */ (function () {
    function IgxCheckboxComponent() {
        this.focused = false;
        this.id = "igx-checkbox-" + nextId++;
        this.labelId = this.id + "-label";
        this.tabindex = null;
        this.labelPosition = LabelPosition.AFTER;
        this.disableRipple = false;
        this.ariaLabelledBy = this.labelId;
        this.ariaLabel = null;
        this.change = new EventEmitter();
        this.cssClass = "igx-checkbox";
        this.indeterminate = false;
        this.checked = false;
        this.disabled = false;
        this._onTouchedCallback = noop;
        this._onChangeCallback = noop;
    }
    IgxCheckboxComponent.prototype.toggle = function () {
        if (this.disabled) {
            return;
        }
        this.indeterminate = false;
        this.checked = !this.checked;
        this.change.emit({ checked: this.checked, checkbox: this });
        this._onChangeCallback(this.checked);
    };
    IgxCheckboxComponent.prototype._onCheckboxChange = function (event) {
        // We have to stop the original checkbox change event
        // from bubbling up since we emit our own change event
        event.stopPropagation();
    };
    IgxCheckboxComponent.prototype._onCheckboxClick = function (event) {
        // Since the original checkbox is hidden and the label
        // is used for styling and to change the checked state of the checkbox,
        // we need to prevent the checkbox click event from bubbling up
        // as it gets triggered on label click
        event.stopPropagation();
        this.toggle();
    };
    IgxCheckboxComponent.prototype._onLabelClick = function (event) {
        // We use a span element as a placeholder label
        // in place of the native label, we need to emit
        // the change event separately here alongside
        // the click event emitted on click
        this.toggle();
    };
    IgxCheckboxComponent.prototype.onFocus = function (event) {
        this.focused = true;
    };
    IgxCheckboxComponent.prototype.onBlur = function (event) {
        this.focused = false;
        this._onTouchedCallback();
    };
    IgxCheckboxComponent.prototype.writeValue = function (value) {
        this._value = value;
        this.checked = !!this._value;
    };
    Object.defineProperty(IgxCheckboxComponent.prototype, "labelClass", {
        get: function () {
            switch (this.labelPosition) {
                case LabelPosition.BEFORE:
                    return this.cssClass + "__label--before";
                case LabelPosition.AFTER:
                default:
                    return this.cssClass + "__label";
            }
        },
        enumerable: true,
        configurable: true
    });
    IgxCheckboxComponent.prototype.registerOnChange = function (fn) { this._onChangeCallback = fn; };
    IgxCheckboxComponent.prototype.registerOnTouched = function (fn) { this._onTouchedCallback = fn; };
    IgxCheckboxComponent.decorators = [
        { type: Component, args: [{
                    providers: [{ provide: NG_VALUE_ACCESSOR, useExisting: IgxCheckboxComponent, multi: true }],
                    selector: "igx-checkbox",
                    preserveWhitespaces: false,
                    template: "<input #checkbox class=\"igx-checkbox__input\" type=\"checkbox\" [attr.id]=\"id\" [attr.name]=\"name\" [attr.value]=\"value\" [attr.tabindex]=\"tabindex\"     [attr.disabled]=\"disabled ? true : null\" [indeterminate]=\"indeterminate\" [checked]=\"checked\" [attr.aria-checked]=\"checked\"     [attr.aria-labelledby]=\"ariaLabelledBy\" [attr.aria-label]=\"ariaLabel\" (change)=\"_onCheckboxChange($event)\" (click)=\"_onCheckboxClick($event)\"     (focus)=\"onFocus($event)\" (blur)=\"onBlur($event)\">  <label #label class=\"igx-checkbox__composite\" igxRipple [igxRippleDisabled]=\"disableRipple\" [igxRippleCentered]=\"true\" [igxRippleDuration]=\"100\"     igxRippleTarget=\".igx-checkbox__ripple\" [attr.for]=\"id\">     <svg class=\"igx-checkbox__composite-mark\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\">         <path d=\"M4.1,12.7 9,17.6 20.3,6.3\" />     </svg>     <div class=\"igx-checkbox__ripple\"></div> </label>  <span #placeholderLabel [attr.id]=\"labelId\" [class]=\"labelClass\" role=\"label\" (click)=\"_onLabelClick($event)\">     <ng-content></ng-content> </span>"
                },] },
    ];
    /** @nocollapse */
    IgxCheckboxComponent.ctorParameters = function () { return []; };
    IgxCheckboxComponent.propDecorators = {
        "nativeCheckbox": [{ type: ViewChild, args: ["checkbox",] },],
        "nativeLabel": [{ type: ViewChild, args: ["label",] },],
        "placeholderLabel": [{ type: ViewChild, args: ["placeholderLabel",] },],
        "id": [{ type: Input },],
        "labelId": [{ type: Input },],
        "value": [{ type: Input },],
        "name": [{ type: Input },],
        "tabindex": [{ type: Input },],
        "labelPosition": [{ type: Input },],
        "disableRipple": [{ type: Input },],
        "ariaLabelledBy": [{ type: Input, args: ["aria-labelledby",] },],
        "ariaLabel": [{ type: Input, args: ["aria-label",] },],
        "change": [{ type: Output },],
        "cssClass": [{ type: HostBinding, args: ["class.igx-checkbox",] },],
        "indeterminate": [{ type: HostBinding, args: ["class.igx-checkbox--indeterminate",] }, { type: Input },],
        "checked": [{ type: HostBinding, args: ["class.igx-checkbox--checked",] }, { type: Input },],
        "disabled": [{ type: HostBinding, args: ["class.igx-checkbox--disabled",] }, { type: Input },],
    };
    return IgxCheckboxComponent;
}());
export { IgxCheckboxComponent };
var IgxCheckboxModule = /** @class */ (function () {
    function IgxCheckboxModule() {
    }
    IgxCheckboxModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxCheckboxComponent],
                    exports: [IgxCheckboxComponent],
                    imports: [IgxRippleModule]
                },] },
    ];
    /** @nocollapse */
    IgxCheckboxModule.ctorParameters = function () { return []; };
    return IgxCheckboxModule;
}());
export { IgxCheckboxModule };
export { ɵ0 };
//# sourceMappingURL=checkbox.component.js.map