import { AfterContentInit, AfterViewInit, ChangeDetectorRef, ComponentFactoryResolver, ElementRef, EventEmitter, IterableDiffers, NgZone, OnDestroy, OnInit, QueryList, TemplateRef, ViewContainerRef } from "@angular/core";
import { Subject } from "rxjs/Subject";
import { DataType } from "../data-operations/data-util";
import { FilteringLogic, IFilteringExpression } from "../data-operations/filtering-expression.interface";
import { ISortingExpression, SortingDirection } from "../data-operations/sorting-expression.interface";
import { IgxForOfDirective } from "../directives/for-of/for_of.directive";
import { IgxGridAPIService } from "./api.service";
import { IgxGridCellComponent } from "./cell.component";
import { IgxColumnComponent } from "./column.component";
import { ISummaryExpression } from "./grid-summary";
import { IgxGridRowComponent } from "./row.component";
export interface IGridCellEventArgs {
    cell: IgxGridCellComponent;
    event: Event;
}
export interface IGridEditEventArgs {
    row: IgxGridRowComponent;
    cell: IgxGridCellComponent;
    currentValue: any;
    newValue: any;
}
export interface IPinColumnEventArgs {
    column: IgxColumnComponent;
    insertAtIndex: number;
}
export interface IPageEventArgs {
    previous: number;
    current: number;
}
export interface IRowDataEventArgs {
    data: any;
}
/**
 * **Ignite UI for Angular Grid** -
 * [Documentation](https://www.infragistics.com/products/ignite-ui-angular/angular/components/grid.html)
 *
 * The Ignite UI Grid is used for presenting and manipulating tabular data in the simplest way possible.  Once data
 * has been bound, it can be manipulated through filtering, sorting & editing operations.
 *
 * Example:
 * ```html
 * <igx-grid [data]="employeeData" autoGenerate="false">
 *   <igx-column field="first" header="First Name"></igx-column>
 *   <igx-column field="last" header="Last Name"></igx-column>
 *   <igx-column field="role" header="Role"></igx-column>
 * </igx-grid>
 * ```
 */
export declare class IgxGridComponent implements OnInit, OnDestroy, AfterContentInit, AfterViewInit {
    private gridAPI;
    private elementRef;
    private zone;
    private document;
    cdr: ChangeDetectorRef;
    private resolver;
    private differs;
    private viewRef;
    data: any[];
    autoGenerate: boolean;
    id: string;
    filteringLogic: FilteringLogic;
    filteringExpressions: any[];
    paging: boolean;
    page: number;
    perPage: number;
    paginationTemplate: TemplateRef<any>;
    height: any;
    width: any;
    readonly headerWidth: number;
    evenRowCSS: string;
    oddRowCSS: string;
    rowHeight: number;
    columnWidth: string;
    onSelection: EventEmitter<IGridCellEventArgs>;
    onColumnPinning: EventEmitter<IPinColumnEventArgs>;
    /**
     * An @Output property emitting an event when cell or row editing has been performed in the grid.
     * On cell editing, both cell and row objects in the event arguments are defined for the corresponding
     * cell that is being edited and the row the cell belongs to.
     * On row editing, only the row object is defined, for the row that is being edited.
     * The cell object is null on row editing.
     */
    onEditDone: EventEmitter<IGridEditEventArgs>;
    onColumnInit: EventEmitter<IgxColumnComponent>;
    onSortingDone: EventEmitter<ISortingExpression>;
    onFilteringDone: EventEmitter<IFilteringExpression>;
    onPagingDone: EventEmitter<IPageEventArgs>;
    onRowAdded: EventEmitter<IRowDataEventArgs>;
    onRowDeleted: EventEmitter<IRowDataEventArgs>;
    columnList: QueryList<IgxColumnComponent>;
    rowList: QueryList<IgxGridRowComponent>;
    parentVirtDir: IgxForOfDirective<any>;
    verticalScrollContainer: IgxForOfDirective<any>;
    scr: ElementRef;
    paginator: ElementRef;
    headerContainer: IgxForOfDirective<any>;
    theadRow: ElementRef;
    tfoot: ElementRef;
    tabindex: number;
    hostClass: string;
    hostRole: string;
    readonly pipeTrigger: number;
    sortingExpressions: any[];
    pagingState: any;
    calcWidth: number;
    calcHeight: number;
    cellInEditMode: IgxGridCellComponent;
    eventBus: Subject<boolean>;
    protected destroy$: Subject<boolean>;
    protected _perPage: number;
    protected _page: number;
    protected _paging: boolean;
    protected _pipeTrigger: number;
    protected _columns: IgxColumnComponent[];
    protected _pinnedColumns: IgxColumnComponent[];
    protected _unpinnedColumns: IgxColumnComponent[];
    protected _filteringLogic: FilteringLogic;
    protected _filteringExpressions: any[];
    protected _sortingExpressions: any[];
    private resizeHandler;
    private columnListDiffer;
    constructor(gridAPI: IgxGridAPIService, elementRef: ElementRef, zone: NgZone, document: any, cdr: ChangeDetectorRef, resolver: ComponentFactoryResolver, differs: IterableDiffers, viewRef: ViewContainerRef);
    ngOnInit(): void;
    ngAfterContentInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    readonly nativeElement: any;
    readonly pinnedWidth: number;
    readonly unpinnedWidth: number;
    readonly columns: IgxColumnComponent[];
    readonly pinnedColumns: IgxColumnComponent[];
    readonly unpinnedColumns: IgxColumnComponent[];
    getColumnByName(name: string): IgxColumnComponent;
    getRowByIndex(index: number): IgxGridRowComponent;
    readonly visibleColumns: IgxColumnComponent[];
    getCellByColumn(rowIndex: number, columnField: string): IgxGridCellComponent;
    readonly totalPages: number;
    readonly totalRecords: number;
    readonly isFirstPage: boolean;
    readonly isLastPage: boolean;
    nextPage(): void;
    previousPage(): void;
    paginate(val: number): void;
    markForCheck(): void;
    addRow(data: any): void;
    deleteRow(rowIndex: number): void;
    updateCell(value: any, rowIndex: number, column: string): void;
    updateRow(value: any, rowIndex: number): void;
    sort(...rest: any[]): void;
    filter(...rest: any[]): void;
    filterGlobal(value: any, condition?: any, ignoreCase?: any): void;
    enableSummaries(...rest: any[]): void;
    disableSummaries(...rest: any[]): void;
    clearFilter(name?: string): void;
    clearSort(name?: string): void;
    clearSummaryCache(): void;
    pinColumn(columnName: string): boolean;
    unpinColumn(columnName: string): void;
    readonly hasSortableColumns: boolean;
    readonly hasEditableColumns: boolean;
    readonly hasFilterableColumns: boolean;
    readonly hasSummarizedColumns: boolean;
    readonly selectedCells: IgxGridCellComponent[] | any[];
    protected calculateGridSizes(): void;
    /**
     * Gets calculated width of the start pinned area
     * @param takeHidden If we should take into account the hidden columns in the pinned area
     */
    protected getPinnedWidth(takeHidden?: boolean): number;
    /**
     * Gets calculated width of the unpinned area
     * @param takeHidden If we should take into account the hidden columns in the pinned area
     */
    protected getUnpinnedWidth(takeHidden?: boolean): number;
    protected _sort(name: string, direction?: SortingDirection, ignoreCase?: boolean): void;
    protected _sortMultiple(expressions: ISortingExpression[]): void;
    protected _filter(name: string, value: any, condition?: any, ignoreCase?: any): void;
    protected _filterMultiple(expressions: IFilteringExpression[]): void;
    protected _summaries(fieldName: string, hasSummary: boolean, summaryOperand?: any): void;
    protected _multipleSummaries(expressions: ISummaryExpression[], hasSummary: boolean): void;
    protected _disableMultipleSummaries(expressions: string[], hasSummary: boolean): void;
    protected resolveDataTypes(rec: any): DataType;
    protected autogenerateColumns(): void;
    protected initColumns(collection: QueryList<IgxColumnComponent>, cb?: any): void;
    protected setEventBusSubscription(): void;
    protected setVerticalScrollSubscription(): void;
}
