var WorksheetDataDictionary = /** @class */ (function () {
    function WorksheetDataDictionary(columnCount, columnWidth) {
        this._dictionary = {};
        this._stringWidthDictionary = {};
        this._counter = 0;
        this.dirtyKeyCollections();
        this._calculateColumnWidth = !columnWidth;
        this._columnWidths = new Array(columnCount);
        if (!this._calculateColumnWidth) {
            this._columnWidths.fill(columnWidth);
        }
    }
    Object.defineProperty(WorksheetDataDictionary.prototype, "columnWidths", {
        get: function () {
            return this._columnWidths;
        },
        enumerable: true,
        configurable: true
    });
    WorksheetDataDictionary.prototype.saveValue = function (value, column) {
        var sanitizedValue = this.sanitizeValue(value);
        if (this._dictionary[sanitizedValue] === undefined) {
            this._dictionary[sanitizedValue] = this._counter++;
            this.dirtyKeyCollections();
        }
        if (this._calculateColumnWidth) {
            var width = this.getTextWidth(value);
            var maxWidth = Math.max(this._columnWidths[column] || 0, width);
            this._columnWidths[column] = maxWidth;
        }
        return this.getSanitizedValue(sanitizedValue);
    };
    WorksheetDataDictionary.prototype.getValue = function (value) {
        return this.getSanitizedValue(this.sanitizeValue(value));
    };
    WorksheetDataDictionary.prototype.getSanitizedValue = function (sanitizedValue) {
        return this._dictionary[sanitizedValue];
    };
    WorksheetDataDictionary.prototype.getKeys = function () {
        if (!this._keysAreValid) {
            this._keys = Object.keys(this._dictionary);
            this._keysAreValid = true;
        }
        return this._keys;
    };
    WorksheetDataDictionary.prototype.getTextWidth = function (text) {
        if (this._stringWidthDictionary[text] === undefined) {
            var context = this.getContext();
            var metrics = context.measureText(text);
            this._stringWidthDictionary[text] = metrics.width + WorksheetDataDictionary.TEXT_PADDING;
        }
        return this._stringWidthDictionary[text];
    };
    WorksheetDataDictionary.prototype.getContext = function () {
        if (!this._context) {
            var canvas = document.createElement("canvas");
            this._context = canvas.getContext("2d");
            this._context.font = WorksheetDataDictionary.DEFAULT_FONT;
        }
        return this._context;
    };
    WorksheetDataDictionary.prototype.sanitizeValue = function (value) {
        return value.replace(/&/g, "&amp;")
            .replace(/</g, "&lt;")
            .replace(/>/g, "&gt;")
            .replace(/"/g, "&quot;")
            .replace(/'/g, "&apos;");
    };
    WorksheetDataDictionary.prototype.dirtyKeyCollections = function () {
        this._keysAreValid = false;
    };
    WorksheetDataDictionary.DEFAULT_FONT = "11pt Calibri";
    WorksheetDataDictionary.TEXT_PADDING = 5;
    return WorksheetDataDictionary;
}());
export { WorksheetDataDictionary };
//# sourceMappingURL=worksheet-data-dictionary.js.map